<?php

declare(strict_types=1);

namespace Drupal\entity_sync_mailgun\EntitySync\Api;

use Drupal\entity_sync\Client\ProviderClientFactoryInterface;

/**
 * Factory for generating Mailgun message v4 API clients.
 *
 * Supported parameters:
 * - api_key: (string, required) The Mailgun API key.
 * - domain: (string, required) The Mailgun domain to which the messages are
 *   related.
 * - endpoint (string, optional): The Mailgun base endpoint to send the requests
 *   to. If not provided no endpoint will be included in the requests and
 *   Mailgun will default to the endpoint for US.
 */
class MessageClientFactory implements ProviderClientFactoryInterface {

  /**
   * {@inheritdoc}
   */
  public function get($sync_id, array $parameters) {
    $required_parameters = [
      'api_key',
      'domain',
    ];
    foreach ($required_parameters as $required_parameter) {
      if (!in_array($required_parameter, array_keys($parameters))) {
        throw new \InvalidArgumentException(sprintf(
          'Parameter "%s" is required for creating the Mailgun message client.',
          $required_parameter
        ));
      }
    }

    return new MessageClient(
      $parameters['api_key'],
      $parameters['domain'],
      $parameters['endpoint'] ?? NULL
    );
  }

}
