<?php

declare(strict_types=1);

namespace Drupal\entity_sync_mailgun\Plugin\EntitySync\OperationConfigurator;

use Drupal\entity_sync\OperationConfigurator\DefaultPluginBase;
use Drupal\entity_sync\OperationConfigurator\FieldTrait\EntityTrait;

/**
 * Plugin for operations that act on individual entities.
 *
 * That is, for operations synchronizing individual entities between Drupal and
 * Mailgun. Currently only exports are supported; it has been tested with
 * messages only even though it should work with domains as well with a change
 * in the client factory that can be overridden at the synchronization
 * configuration using it. Support for imports should be added in this plugin.
 *
 * phpcs:disable
 * @EntitySyncOperationConfigurator(
 *   id = "mailgun_entity",
 *   label = @Translation("Mailgun entity export"),
 *   description = @Translation(
 *     "Use 'Mailgun entity import' types to export Drupal entities into Mailgun messages/domains."
 *   ),
 *   action_types = {
 *     "export_entity",
 *   },
 *   workflow_id = "entity_sync_operation_default",
 * )
 * phpcs:enable
 */
class Entity extends DefaultPluginBase {

  use EntityTrait;

  /**
   * The ID of the operation runner service.
   */
  const RUNNER_SERVICE_ID = 'entity_sync.runner.entity_export';

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'action_type' => NULL,
      'local_entity' => [],
      'remote_resource' => [
        'id_field' => 'id',
        'client' => [
          'type' => 'factory',
          'service' => 'entity_sync_mailgun.entity_sync_client.entity_factory',
          'parameters' => [],
        ],
      ],
      'operations' => [],
      'field_mapping' => [],
      'ui' => [
        'disallowed_transitions' => [
          'fail',
          'complete',
        ],
        'uneditable_states' => [
          'cancelled',
          'running',
          'completed',
          'failed',
        ],
      ],
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function bundleFieldDefinitions() {
    $fields = parent::bundleFieldDefinitions();

    // Add the dynamic entity reference field.
    $fields += $this->buildEntityBundleFieldDefinitions();

    return $fields;
  }

}
