<?php

declare(strict_types=1);

namespace Drupal\entity_sync_mailgun\Plugin\EntitySync\OperationConfigurator;

use Drupal\entity_sync\OperationConfigurator\DefaultPluginBase;

/**
 * Plugin for operations that act on lists of entities.
 *
 * That is, for operations synchronizing lists of entities between Drupal and
 * Mailgun. Currently only imports are supported; ; it has been tested with
 * messages only even though it should work with events as well with a change
 * in the client factory that can be overridden at the synchronization
 * configuration using it. Support for exports should be added in this plugin.
 *
 * phpcs:disable
 * @EntitySyncOperationConfigurator(
 *   id = "mailgun_entity_list",
 *   label = @Translation("Mailgun entity list import"),
 *   description = @Translation(
 *     "Use 'Mailgun list import' types to import a list of Mailgun messages/events into Drupal entities."
 *   ),
 *   action_types = {
 *     "import_list",
 *   },
 *   workflow_id = "entity_sync_operation_default",
 * )
 * phpcs:enable
 */
class EntityList extends DefaultPluginBase {

  /**
   * The ID of the operation runner service.
   */
  const RUNNER_SERVICE_ID = 'entity_sync.runner.entity_import_list';

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'action_type' => NULL,
      'local_entity' => [],
      'remote_resource' => [
        'id_field' => 'id',
        'client' => [
          'type' => 'factory',
          'service' => 'entity_sync_mailgun.entity_sync_client.entity_factory',
          'parameters' => [],
        ],
      ],
      'operations' => [],
      'field_mapping' => [],
      'ui' => [
        'disallowed_transitions' => [
          'fail',
          'complete',
        ],
        'uneditable_states' => [
          'cancelled',
          'running',
          'completed',
          'failed',
        ],
      ],
    ] + parent::defaultConfiguration();
  }

}
